@@ -1,5 +1,5 @@
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from vng_api_common.caching import ETagMixin
 from vng_api_common.descriptors import GegevensGroepType
