@@ -6,7 +6,7 @@ from typing import Any, Dict, List, Optional
 from django.conf import settings
 from django.db import models, transaction
 from django.db.models import QuerySet
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 import jwt
 from djangorestframework_camel_case.util import underscoreize
@@ -101,6 +101,7 @@ class JWTAuth:
                     self.encoded,
                     algorithms=["HS256"],
                     options={"verify_signature": False},
+                    leeway=settings.JWT_LEEWAY,
                 )
             except jwt.DecodeError:
                 logger.info("Invalid JWT encountered")
@@ -134,7 +135,12 @@ class JWTAuth:
 
             # check signature of the token
             try:
-                payload = jwt.decode(self.encoded, key, algorithms="HS256")
+                payload = jwt.decode(
+                    self.encoded,
+                    key,
+                    algorithms="HS256",
+                    leeway=settings.JWT_LEEWAY,
+                )
             except jwt.InvalidSignatureError:
                 logger.exception("Invalid signature - possible payload tampering?")
                 raise PermissionDenied(
