@@ -1,5 +1,5 @@
 from django.contrib import admin, messages
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from requests.exceptions import RequestException
 from solo.admin import SingletonModelAdmin
